Changing org.onlab.onos package to org.onosproject

Change-Id: Ic81421faa27acdcff045add47d9e0a715cd4f575
diff --git a/core/api/src/main/java/org/onosproject/net/provider/ProviderId.java b/core/api/src/main/java/org/onosproject/net/provider/ProviderId.java
index 62207d9..2c959af 100644
--- a/core/api/src/main/java/org/onosproject/net/provider/ProviderId.java
+++ b/core/api/src/main/java/org/onosproject/net/provider/ProviderId.java
@@ -13,7 +13,7 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
-package org.onlab.onos.net.provider;
+package org.onosproject.net.provider;
 
 import java.util.Objects;
 
@@ -21,7 +21,7 @@
 import static com.google.common.base.Preconditions.checkNotNull;
 
 /**
  * External identity of a {@link org.onlab.onos.net.provider.Provider} family.
  * It also carriers two designations of external characteristics, the URI
  * scheme and primary/ancillary indicator.
  * <p>
@@ -30,7 +30,7 @@
  * a provider as a primary or ancillary.
  * </p>
  * <p>
  * A {@link org.onlab.onos.net.provider.ProviderRegistry} uses this designation
  * to permit only one primary provider per device URI scheme. Multiple
  * ancillary providers can register with the same device URI scheme however.
  * </p>
@@ -56,7 +56,7 @@
     /**
      * Creates a new primary provider identifier from the specified string.
      * The providers are expected to follow the reverse DNS convention, e.g.
-     * {@code org.onlab.onos.provider.of.device}
+     * {@code org.onosproject.provider.of.device}
      *
      * @param scheme device URI scheme to which this provider is bound, e.g. "of", "snmp"
      * @param id     string identifier
@@ -68,7 +68,7 @@
     /**
      * Creates a new provider identifier from the specified string.
      * The providers are expected to follow the reverse DNS convention, e.g.
-     * {@code org.onlab.onos.provider.of.device}
+     * {@code org.onosproject.provider.of.device}
      *
      * @param scheme    device URI scheme to which this provider is bound, e.g. "of", "snmp"
      * @param id        string identifier
@@ -21,7 +21,7 @@
 
 /**
- * External identity of a {@link org.onlab.onos.net.provider.Provider} family.
+ * External identity of a {@link org.onosproject.net.provider.Provider} family.
  * It also carriers two designations of external characteristics, the URI
  * scheme and primary/ancillary indicator.
@@ -30,7 +30,7 @@
  * </p>
  * <p>
- * A {@link org.onlab.onos.net.provider.ProviderRegistry} uses this designation
+ * A {@link org.onosproject.net.provider.ProviderRegistry} uses this designation
  * to permit only one primary provider per device URI scheme. Multiple
  * ancillary providers can register with the same device URI scheme however.